# PharmaPy

<img align="left" src="./doc/online_docs/images/PharmaPy_logo.jpeg" alt="PharmaPy_logo" height="250">

<!-- BEGIN Status badges -->
![GitHub all releases](https://img.shields.io/github/downloads/CryPTSys/PharmaPy/total)
[![DOI](https://img.shields.io/badge/DOI-10.1016%2Fj.compchemeng.2021.107408-blue)](https://www.sciencedirect.com/science/article/abs/pii/S0098135421001861)
<!-- END Status badges -->

PharmaPy is a pythonic library for the analysis of pharmaceutical manufacturing systems.

It allows to simulate the dynamics of standalone, drug substance unit operations in a variety of operating modes (batch, continuous, semibatch). Also, PharmaPy facilitates setting up and simulating pharmaceutical **flowsheets**, i.e., interconnected unit operations running in one or more operation modes, offering flexibility to simulate end-to-end batch, end-to-end continuous, and hybrid operation schemes (combination of batch and/or continuous and semicontinuous unit operations).

<br clear="left"/>

## Getting started
To install PharmaPy, download and unzip the code from the release section, and then follow the instructions on the `install_instructions.txt` file.

Read our [link to documentation page] for more information on how to install and how to use PharmaPy.



